import { API, HAP, PlatformAccessory } from "homebridge";
import { ProtectApi, ProtectEventPacket, ProtectNvrConfig } from "unifi-protect";
import { ProtectDeviceConfigTypes, ProtectLogging } from "./protect-types.js";
import { ProtectNvr } from "./protect-nvr.js";
import { ProtectPlatform } from "./protect-platform.js";
export interface ProtectHints {
    hardwareDecoding: boolean;
    hardwareTranscoding: boolean;
    ledStatus: boolean;
    logDoorbell: boolean;
    logHksv: boolean;
    logMotion: boolean;
    motionDuration: number;
    occupancyDuration: number;
    probesize: number;
    smartDetect: boolean;
    smartOccupancy: string[];
    syncName: boolean;
    timeshift: boolean;
    transcode: boolean;
    transcodeHighLatency: boolean;
    twoWayAudio: boolean;
}
export declare abstract class ProtectBase {
    readonly api: API;
    private debug;
    protected readonly hap: HAP;
    readonly log: ProtectLogging;
    readonly nvr: ProtectNvr;
    ufpApi: ProtectApi;
    readonly platform: ProtectPlatform;
    constructor(nvr: ProtectNvr);
    protected setInfo(accessory: PlatformAccessory, device: ProtectDeviceConfigTypes | ProtectNvrConfig): boolean;
    get name(): string;
}
export declare abstract class ProtectDevice extends ProtectBase {
    accessory: PlatformAccessory;
    hints: ProtectHints;
    protected listeners: {
        [index: string]: (packet: ProtectEventPacket) => void;
    };
    abstract ufp: ProtectDeviceConfigTypes;
    constructor(nvr: ProtectNvr, accessory: PlatformAccessory);
    protected configureHints(): boolean;
    configureInfo(): boolean;
    cleanup(): void;
    protected configureMotionSensor(isEnabled?: boolean, isInitialized?: boolean): boolean;
    private configureMotionSwitch;
    private configureMotionTrigger;
    private configureMqttMotionTrigger;
    protected configureOccupancySensor(isEnabled?: boolean, isInitialized?: boolean): boolean;
    getFeatureFloat(option: string): number | undefined;
    getFeatureNumber(option: string): number | undefined;
    getFeatureValue(option: string): string | undefined;
    hasFeature(option: string): boolean;
    isReservedName(name: string | undefined): boolean;
    get isOnline(): boolean;
    get id(): string;
    get name(): string;
    get accessoryName(): string;
    set accessoryName(name: string);
}
