/// <reference types="node" />
import { ProtectApi, ProtectNvrConfig } from "unifi-protect";
import { ProtectDeviceConfigTypes, ProtectDevices, ProtectLogging } from "./protect-types.js";
import { ProtectNvrOptions } from "./protect-options.js";
import { ProtectDevice } from "./protect-device.js";
import { ProtectMqtt } from "./protect-mqtt.js";
import { ProtectNvrEvents } from "./protect-nvr-events.js";
import { ProtectNvrSystemInfo } from "./protect-nvr-systeminfo.js";
import { ProtectPlatform } from "./protect-platform.js";
export declare class ProtectNvr {
    private api;
    config: ProtectNvrOptions;
    private deviceRemovalQueue;
    readonly configuredDevices: {
        [index: string]: ProtectDevices;
    };
    events: ProtectNvrEvents;
    private isEnabled;
    private hap;
    private liveviews;
    logApiErrors: boolean;
    readonly log: ProtectLogging;
    mqtt: ProtectMqtt | null;
    private name;
    nvrHksvErrors: number;
    nvrOptions: ProtectNvrOptions;
    platform: ProtectPlatform;
    systemInfo: ProtectNvrSystemInfo | null;
    ufp: ProtectNvrConfig;
    ufpApi: ProtectApi;
    private unsupportedDevices;
    constructor(platform: ProtectPlatform, nvrOptions: ProtectNvrOptions);
    private bootstrapNvr;
    login(): Promise<void>;
    private configureNvr;
    private configureDefaultDoorbellMessage;
    private addProtectDevice;
    private discoverDevices;
    addHomeKitDevice(device: ProtectDeviceConfigTypes): ProtectDevice | null;
    private discoverAndSyncAccessories;
    private cleanupDevices;
    removeHomeKitDevice(protectDevice: ProtectDevice): void;
    private removeHomeKitAccessories;
    private servePlaylist;
    resetNvrConnection(): Promise<void>;
    deviceLookup(deviceId: string): ProtectDevices | null;
    getFeatureFloat(option: string): number | undefined;
    getFeatureNumber(option: string): number | undefined;
    hasFeature(option: string): boolean;
    optionEnabled(device: ProtectDeviceConfigTypes | ProtectNvrConfig | null, option?: string, defaultReturnValue?: boolean): boolean;
    sleep(sleepTimer: number): Promise<NodeJS.Timeout>;
    private retry;
}
